#[non_exhaustive]pub struct BridgeInfo {
pub origination_uuid: Option<String>,
pub target_channel: String,
}Expand description
What a bridge() argument list says about the leg it is about to create.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.origination_uuid: Option<String>The UUID the new leg is being forced to take, when the dial string sets one.
target_channel: StringThe first endpoint with its {}/[] variables removed, matching the form
the new channel will report as its channel name.